@@ -29,7 +29,7 @@ class Badge(models.Model):
     
     @property
     def meta_badge(self):
-        from utils import registered_badges
+        from .utils import registered_badges
         return registered_badges[self.id]
     
     @property
@@ -77,3 +77,6 @@ class BadgeToUser(models.Model):
     user = models.ForeignKey(User)
     
     created = models.DateTimeField(default=datetime.now)
+
+
+from . import listeners
\ No newline at end of file
